# Conditional for release and snapshot builds. Uncomment for release-builds.
%global rel_build 1

# This is needed, because src-url contains branched part of versioning-scheme.
%global branch 1.23

# Settings used for build from snapshots.
%{!?rel_build:%global commit 4115bb9ec815227fa651cab1a27aa33a1a4c3827}
%{!?rel_build:%global commit_date 20151006}
%{!?rel_build:%global shortcommit %(c=%{commit};echo ${c:0:7})}
%{!?rel_build:%global git_ver git%{commit_date}-%{shortcommit}}
%{!?rel_build:%global git_rel .git%{commit_date}.%{shortcommit}}
%{!?rel_build:%global git_tar %{name}-%{version}-%{git_ver}.tar.xz}

Name:           mate-panel
Version:        %{branch}.3
%if 0%{?rel_build}
Release:        1%{?dist}
%else
Release:        10.1%{?git_rel}%{?dist}
%endif
Summary:        MATE Desktop panel and applets
#libs are LGPLv2+ applications GPLv2+
License:        GPLv2+
URL:            http://mate-desktop.org

# for downloading the tarball use 'spectool -g -R mate-panel.spec'
# Source for release-builds.
%{?rel_build:Source0:     http://pub.mate-desktop.org/releases/%{branch}/%{name}-%{version}.tar.xz}
# Source for snapshot-builds.
%{!?rel_build:Source0:    http://git.mate-desktop.org/%{name}/snapshot/%{name}-%{commit}.tar.xz#/%{git_tar}}

Source1:        mate-panel_fedora-30.layout
Source2:        mate-panel_fedora-28.layout
Source3:        mate-panel_rhel.layout

# https://github.com/mate-desktop/mate-panel/pull/816
#Patch1:         mate-panel_0001-struts-Create-struts-for-panels-on-inside-edges-of-m.patch
#Patch2:         mate-panel_0002-struts-Use-inside-edge-panels-only-on-Marco-and-Meta.patch

Requires:       %{name}-libs%{?_isa} = %{version}-%{release}
#for fish
Recommends:     fortune-mod
# rhbz (#1007219)
Requires:       caja-schemas

BuildRequires:  desktop-file-utils
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk3-devel
BuildRequires:  gtk-layer-shell-devel
BuildRequires:  libcanberra-devel
BuildRequires:  libmateweather-devel
BuildRequires:  libwnck3-devel
BuildRequires:  librsvg2-devel
BuildRequires:  libSM-devel
BuildRequires:  mate-common
BuildRequires:  mate-desktop-devel
BuildRequires:  mate-menus-devel
BuildRequires:  yelp-tools

%description
MATE Desktop panel applets

%package libs
Summary:     Shared libraries for mate-panel
License:     LGPLv2+
Requires:    %{name}%{?_isa} = %{version}-%{release}

%description libs
Shared libraries for libmate-desktop

%package devel
Summary:     Development files for mate-panel
Requires:    %{name}-libs%{?_isa} = %{version}-%{release}

%description devel
Development files for mate-panel

%prep
%if 0%{?rel_build}
%autosetup -p1
%else
%autosetup -n %{name}-%{commit} -p1
%endif

%if 0%{?rel_build}
#NOCONFIGURE=1 ./autogen.sh
%else # 0%{?rel_build}
# needed for git snapshots
NOCONFIGURE=1 ./autogen.sh
%endif # 0%{?rel_build}

%build

#libexecdir needed for gnome conflicts
%configure                                        \
           --disable-static                       \
           --disable-schemas-compile              \
           --libexecdir=%{_libexecdir}/mate-panel \
           --enable-introspection                 \
           --disable-gtk-doc                      \
           --enable-x11                           \
           --enable-wayland                       \
           --with-in-process-applets=none
#           --with-in-process-applets=wncklet,clock,notification-area

# remove unused-direct-shlib-dependency
sed -i -e 's! -shared ! -Wl,--as-needed\0!g' libtool

make  %{?_smp_mflags} V=1


%install
%{make_install}

find %{buildroot} -name '*.la' -exec rm -rf {} ';'
find %{buildroot} -name '*.a' -exec rm -rf {} ';'

desktop-file-install \
        --dir=%{buildroot}%{_datadir}/applications \
%{buildroot}%{_datadir}/applications/mate-panel.desktop

%if 0%{?fedora} && 0%{?fedora} >= 30
install -D -m 0644 %{SOURCE1} %{buildroot}%{_datadir}/mate-panel/layouts/fedora.layout
%endif
%if 0%{?fedora} && 0%{?fedora} == 29
install -D -m 0644 %{SOURCE2} %{buildroot}%{_datadir}/mate-panel/layouts/fedora.layout
%endif
%if 0%{?fedora} && 0%{?fedora} == 28
install -D -m 0644 %{SOURCE2} %{buildroot}%{_datadir}/mate-panel/layouts/fedora.layout
%endif
%if 0%{?rhel}
install -D -m 0644 %{SOURCE3} %{buildroot}%{_datadir}/mate-panel/layouts/rhel.layout
%endif

%find_lang %{name} --with-gnome --all-name


%files -f %{name}.lang
%doc AUTHORS COPYING README
%{_mandir}/man1/*
%{_bindir}/mate-desktop-item-edit
%{_bindir}/mate-panel
%{_bindir}/mate-panel-test-applets
%{_libexecdir}/mate-panel
%{_datadir}/glib-2.0/schemas/org.mate.panel.*.xml
%{_datadir}/applications/mate-panel.desktop
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/mate-panel
%{_datadir}/dbus-1/services/org.mate.panel.applet.ClockAppletFactory.service
%{_datadir}/dbus-1/services/org.mate.panel.applet.FishAppletFactory.service
%{_datadir}/dbus-1/services/org.mate.panel.applet.NotificationAreaAppletFactory.service
%{_datadir}/dbus-1/services/org.mate.panel.applet.WnckletFactory.service
#%%{_libdir}/mate-panel/

%files libs
%doc COPYING.LIB
%{_libdir}/libmate-panel-applet-4.so.1*
%{_libdir}/girepository-1.0/MatePanelApplet-4.0.typelib

%files devel
%doc %{_datadir}/gtk-doc/html/mate-panel-applet/
%{_libdir}/libmate-panel-applet-4.so
%{_includedir}/mate-panel-4.0
%{_libdir}/pkgconfig/libmatepanelapplet-4.0.pc
%{_datadir}/gir-1.0/MatePanelApplet-4.0.gir


%changelog
* Thu Jan 23 2020 Wolfgang Ulbrich <fedora@raveit.de> - 1.23.3-1
- update to 1.23.3

* Fri Oct 11 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.23.2-2
- test https://github.com/mate-desktop/mate-panel/pull/1034
- test https://github.com/mate-desktop/mate-panel/commit/f5354df
- use https://github.com/mate-desktop/mate-panel/commit/81fcedf
- test https://github.com/mate-desktop/mate-panel/pull/1039
- local test, increase min iconsize of tray applets
- test https://github.com/mate-desktop/mate-panel/pull/1041
- test https://github.com/mate-desktop/mate-panel/commit/2d88f6f
- test https://github.com/mate-desktop/mate-panel/commit/666ee49
- test https://github.com/mate-desktop/mate-panel/commit/7643b1d
- test https://github.com/mate-desktop/mate-panel/pull/1043

* Fri Oct 11 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.23.2-1
- update to 1.23.2

* Mon Mar 04 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.23.1-2
- test https://github.com/mate-desktop/mate-panel/pull/990
- test https://github.com/mate-desktop/mate-panel/pull/998
- test https://github.com/mate-desktop/mate-panel/commit/6a42665
- test https://github.com/mate-desktop/mate-panel/pull/1000
- use https://github.com/mate-desktop/mate-panel/commit/053315
- use https://github.com/mate-desktop/mate-panel/commit/60c147
- use https://github.com/mate-desktop/mate-panel/commit/950caf
- use https://github.com/mate-desktop/mate-panel/commit/407956
- test https://github.com/mate-desktop/mate-panel/pull/1015
- use https://github.com/mate-desktop/mate-panel/commit/8146d0c
- use https://github.com/mate-desktop/mate-panel/commit/07c80d7
- use https://github.com/mate-desktop/mate-panel/commit/589f4ec
- use https://github.com/mate-desktop/mate-panel/commit/d7bf589
- test https://github.com/mate-desktop/mate-panel/pull/1023
- test https://github.com/mate-desktop/mate-panel/pull/1021

* Mon Mar 04 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.23.1-1
- test 1.23.1

* Mon Mar 04 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.23.0-2
- test https://github.com/mate-desktop/mate-panel/pull/953
- test https://github.com/mate-desktop/mate-panel/pull/958
- test https://github.com/mate-desktop/mate-panel/commit/a7275d5
- test https://github.com/mate-desktop/mate-panel/commit/5497beb
- test https://github.com/mate-desktop/mate-panel/pull/963
- use https://github.com/mate-desktop/mate-panel/commit/a9e6084
- use https://github.com/mate-desktop/mate-panel/commit/894645c
- use https://github.com/mate-desktop/mate-panel/commit/c45e920
- test https://github.com/mate-desktop/mate-panel/pull/985
- use https://github.com/mate-desktop/mate-panel/commit/6224488
- test https://github.com/mate-desktop/mate-panel/pull/986
- add BR gtk-layer-shell-devel, enable wayland build
- test https://github.com/mate-desktop/mate-panel/pull/988
- test https://github.com/mate-desktop/mate-panel/pull/989

* Mon Mar 04 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.23.0-1
- test 1.23.0

* Mon Mar 04 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.22.1-1
- bump version for better testing
- https://github.com/mate-desktop/mate-panel/pull/946
- add volume-applet to fedora layout

* Mon Mar 04 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.22.0-2
- test https://github.com/mate-desktop/mate-panel/pull/936
- test https://github.com/mate-desktop/mate-panel/pull/939
- test https://github.com/mate-desktop/mate-panel/pull/930
- test https://github.com/mate-desktop/mate-panel/pull/931

* Mon Mar 04 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.22.0-1
- update to 1.22.0

* Fri Sep 28 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.4-2
- use https://github.com/mate-desktop/mate-panel/pull/816
- test https://github.com/mate-desktop/mate-panel/pull/916
- test build na-tray in-process
- test https://github.com/mate-desktop/mate-panel/pull/915
- test https://github.com/mate-desktop/mate-panel/pull/919
- test https://github.com/mate-desktop/mate-panel/pull/922
- test https://github.com/mate-desktop/mate-panel/pull/923
- test https://github.com/mate-desktop/mate-panel/pull/929
- test https://github.com/mate-desktop/mate-panel/pull/935
- test https://github.com/mate-desktop/mate-panel/pull/938

* Fri Sep 28 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.4-1
- test 1.21.4
- use https://github.com/mate-desktop/mate-panel/pull/816
- test again https://github.com/mate-desktop/mate-panel/pull/824

* Fri Sep 28 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.3-2
- use https://github.com/mate-desktop/mate-panel/pull/816
- test https://github.com/mate-desktop/mate-panel/pull/891
- test https://github.com/mate-desktop/mate-panel/pull/896
- test https://github.com/mate-desktop/mate-panel/pull/902
- test https://github.com/mate-desktop/mate-panel/pull/903
- test https://github.com/mate-desktop/mate-panel/pull/905
- test https://github.com/mate-desktop/mate-panel/pull/906
- use https://github.com/mate-desktop/mate-panel/commit/ab4812a
- use https://github.com/mate-desktop/mate-panel/commit/793cc25
- test https://github.com/mate-desktop/mate-panel/pull/911, not finished
- test again https://github.com/mate-desktop/mate-panel/pull/824

* Fri Sep 28 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.3-1
- test 1.21.3
- use https://github.com/mate-desktop/mate-panel/pull/816
- test again https://github.com/mate-desktop/mate-panel/pull/824

* Fri Sep 28 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.2-4
- use https://github.com/mate-desktop/mate-panel/pull/816
- test https://github.com/mate-desktop/mate-panel/pull/864
- test again https://github.com/mate-desktop/mate-panel/pull/824
- test https://github.com/mate-desktop/mate-panel/pull/890
- test https://github.com/mate-desktop/mate-panel/pull/856
- add all from from 856 PR

* Fri Sep 28 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.2-3
- use https://github.com/mate-desktop/mate-panel/pull/816
- test https://github.com/mate-desktop/mate-panel/pull/864
- test again https://github.com/mate-desktop/mate-panel/pull/824
- test https://github.com/mate-desktop/mate-panel/pull/890
- test https://github.com/mate-desktop/mate-panel/pull/856
- only add port to GtkGrid from 856

* Fri Sep 28 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.2-2
- use https://github.com/mate-desktop/mate-panel/pull/816
- test https://github.com/mate-desktop/mate-panel/pull/864
- test again https://github.com/mate-desktop/mate-panel/pull/824
- test https://github.com/mate-desktop/mate-panel/pull/890

* Fri Sep 28 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.2-1
- test 1.21.2
- use https://github.com/mate-desktop/mate-panel/pull/816
- test https://github.com/mate-desktop/mate-panel/pull/864

* Tue Mar 27 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.1-3
- test, build all applets out-of-process
- build against gtk+-3.24.0
- drop all version check for building against patched gtk3-3.22.30
- add https://github.com/mate-desktop/mate-panel/commit/7369482
- test https://github.com/mate-desktop/mate-panel/pull/845
- test https://github.com/mate-desktop/mate-panel/pull/846
- test https://github.com/mate-desktop/mate-panel/pull/849
- test fix for windows-list (#849)
- test https://github.com/mate-desktop/mate-panel/pull/863
- test https://github.com/mate-desktop/mate-panel/pull/864
- test https://github.com/mate-desktop/mate-panel/pull/866

* Tue Mar 27 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.1-2
- test https://github.com/mate-desktop/mate-panel/pull/813
- test https://github.com/mate-desktop/mate-panel/pull/816
- test https://github.com/mate-desktop/mate-panel/pull/820
- test https://github.com/mate-desktop/mate-panel/pull/825
- local test, deprecations-2
- local test, gtk_menu_poup
- test style classes
- test https://github.com/mate-desktop/mate-panel/pull/833
- test https://github.com/mate-desktop/mate-panel/commit/9de3a86

* Tue Mar 27 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.1-1
- test 1.21.1

* Tue Mar 27 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.0-5
- use https://github.com/mate-desktop/mate-panel/pull/795
- test https://github.com/mate-desktop/mate-panel/pull/794
- use https://github.com/mate-desktop/mate-panel/pull/806
- build --with-in-process-applets=none

* Tue Mar 27 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.0-4
- test https://github.com/mate-desktop/mate-panel/pull/795
- test https://github.com/mate-desktop/mate-panel/pull/794
- requires new mate-menus
- fixes https://github.com/mate-desktop/mate-panel/issues/797
- fixes https://github.com/mate-desktop/mate-panel/issues/799
- test https://github.com/mate-desktop/mate-panel/pull/806
- build --with-in-process-applets=all for ^^^^

* Tue Mar 27 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.0-3
- test for https://github.com/mate-desktop/mate-panel/issues/797
- build --with-in-process-applets=none

* Tue Mar 27 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.0-2
- test https://github.com/mate-desktop/mate-panel/pull/787
- test https://github.com/mate-desktop/mate-panel/pull/789
- test https://github.com/mate-desktop/mate-panel/pull/795

* Tue Mar 27 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.0-1
- test 1.21.0
- test https://github.com/mate-desktop/mate-panel/pull/787
- test https://github.com/mate-desktop/mate-panel/pull/789

* Tue Mar 27 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.20.1-6
- test https://github.com/mate-desktop/mate-panel/pull/762
- test https://github.com/mate-desktop/mate-panel/pull/766
- use some GtkStock deprecation fixes
- switch to --with-in-process-applets=all
- test https://github.com/mate-desktop/mate-panel/pull/767
- test https://github.com/mate-desktop/mate-panel/pull/776
- test https://github.com/mate-desktop/mate-panel/pull/770
- test https://github.com/mate-desktop/mate-panel/pull/775
- test merged https://github.com/mate-desktop/mate-panel/pull/772
- test merged https://github.com/mate-desktop/mate-panel/pull/771
- test https://github.com/mate-desktop/mate-panel/pull/779
- test https://github.com/mate-desktop/mate-panel/pull/780
- test https://github.com/mate-desktop/mate-panel/pull/782
- fix https://github.com/mate-desktop/mate-panel/issues/773
- fiz rhbz (#1493289)
- recommends  fortune-mod
- test https://github.com/mate-desktop/mate-panel/commit/8670151
- fix https://github.com/mate-desktop/mate-panel/issues/786
- test https://github.com/mate-desktop/mate-panel/pull/789
- bump version to update f28 repo

* Tue Mar 27 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.20.1-1
- update to 1.20.1

* Sun Feb 11 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.20.0-2
- build with --with-in-process-applets=none
- test https://github.com/mate-desktop/mate-panel/pull/734
- test https://github.com/mate-desktop/mate-panel/pull/739
- test https://github.com/mate-desktop/mate-panel/pull/744
- test https://github.com/mate-desktop/mate-panel/pull/747
- test https://github.com/mate-desktop/mate-panel/pull/721
- try fix https://github.com/mate-desktop/mate-panel/issues/711
- test https://github.com/mate-desktop/mate-panel/pull/755
- test https://github.com/mate-desktop/mate-panel/pull/756

* Sun Feb 11 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.20.0-1
- build --with-in-process-applets=all
- update to 1.20.0 release
- drop desktop-database rpm scriptlet
- drop GSettings Schema rpm scriplet
- drop IconCache rpm scriplet
- switch to using autosetup

* Thu Jan 25 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.6-2
- test https://github.com/mate-desktop/mate-panel/pull/714
- test https://github.com/mate-desktop/mate-panel/pull/725

* Thu Jan 25 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.6-1
- test 1.19.6 with hdpi support

* Thu Jan 25 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.5-1
- update to  1.19.5
- test hdpi https://github.com/mate-desktop/mate-panel/pull/710

* Mon Jan 01 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.19.4-1
- build --with-in-process-applets=none
- update to 1.19.4
- test https://github.com/mate-desktop/mate-panel/pull/696
- test https://github.com/mate-desktop/mate-panel/pull/697
- test https://github.com/mate-desktop/mate-panel/pull/700
- use https://github.com/mate-desktop/mate-panel/commit/dd14fcb
- use https://github.com/mate-desktop/mate-panel/commit/3889e17
- use https://github.com/mate-desktop/mate-panel/commit/fd12de4
- use https://github.com/mate-desktop/mate-panel/commit/74c8d77
- use https://github.com/mate-desktop/mate-panel/commit/dfd529d
- use https://github.com/mate-desktop/mate-panel/commit/66ac0a4
- test hdpi https://github.com/mate-desktop/mate-panel/pull/710

* Tue Jun 27 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.19.3-3
- build --with-in-process-applets=none
- use https://github.com/mate-desktop/mate-panel/commit/4a25da5
- use https://github.com/mate-desktop/mate-panel/commit/57d3c8f
- use https://github.com/mate-desktop/mate-panel/commit/2dbcb02
- use https://github.com/mate-desktop/mate-panel/commit/4fbe8e2
- use https://github.com/mate-desktop/mate-panel/commit/8a158fe
- use https://github.com/mate-desktop/mate-panel/commit/c13f02a
- use https://github.com/mate-desktop/mate-panel/commit/cfb9e30
- test https://github.com/mate-desktop/mate-panel/pull/667
- test https://github.com/mate-desktop/mate-panel/pull/671
- test https://github.com/mate-desktop/mate-panel/pull/669
- test https://github.com/mate-desktop/mate-panel/pull/679
- test https://github.com/mate-desktop/mate-panel/pull/683
- test https://github.com/mate-desktop/mate-panel/pull/685
- test https://github.com/mate-desktop/mate-panel/pull/691

* Tue Jun 27 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.19.3-2
- build --with-in-process-applets=none
- use https://github.com/mate-desktop/mate-panel/commit/4a25da5
- use https://github.com/mate-desktop/mate-panel/commit/57d3c8f
- use https://github.com/mate-desktop/mate-panel/commit/2dbcb02
- use https://github.com/mate-desktop/mate-panel/commit/4fbe8e2
- use https://github.com/mate-desktop/mate-panel/commit/8a158fe
- use https://github.com/mate-desktop/mate-panel/commit/c13f02a
- use https://github.com/mate-desktop/mate-panel/commit/cfb9e30
- test https://github.com/mate-desktop/mate-panel/pull/667
- test https://github.com/mate-desktop/mate-panel/pull/671
- test https://github.com/mate-desktop/mate-panel/pull/669
- test https://github.com/mate-desktop/mate-panel/pull/679

* Tue Jun 27 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.19.3-1
- test released 1.19.3
- build --with-in-process-applets=none
- test https://github.com/mate-desktop/mate-panel/pull/593
- test https://github.com/mate-desktop/mate-panel/pull/600
- test https://github.com/mate-desktop/mate-panel/pull/645


* Tue Jun 27 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.19.2-1
- test 1.19.2
- test https://github.com/mate-desktop/mate-panel/pull/593
- test https://github.com/mate-desktop/mate-panel/pull/600

* Tue Jun 27 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.19.1-2
- test https://github.com/mate-desktop/mate-panel/pull/597
- test https://github.com/mate-desktop/mate-panel/pull/593
- try fix https://github.com/mate-desktop/mate-panel/issues/594
- test https://github.com/mate-desktop/mate-panel/pull/601
- test https://github.com/mate-desktop/mate-panel/pull/600
- test https://github.com/mate-desktop/mate-panel/pull/606
- test https://github.com/mate-desktop/mate-panel/pull/607
- test https://github.com/mate-desktop/mate-panel/pull/612
- test https://github.com/mate-desktop/mate-panel/pull/619
- test https://github.com/mate-desktop/mate-panel/pull/618

* Tue Jun 27 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.19.1-1
- test 1.19.1
- disable patches

* Wed May 24 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.19.0-4
- test fix for https://github.com/mate-desktop/mate-panel/issues/305
- test fix for closing menus,
- https://github.com/mate-desktop/mate-panel/commits/menu-hacks
- test fix for https://github.com/mate-desktop/mate-panel/issues/586
- test https://github.com/mate-desktop/mate-panel/pull/597
- test https://github.com/mate-desktop/mate-panel/pull/593

* Wed May 24 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.19.0-3
- fix rhbz (#1440513) , hopefully!
- fix https://github.com/mate-desktop/mate-panel/issues/520
- fix https://github.com/mate-desktop/mate-panel/issues/570

* Tue May 16 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.19.0-2
- use https://github.com/mate-desktop/mate-panel/pull/575

* Thu May 11 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.19.0-1
- update to 1.19.0

* Wed Apr 05 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.18.2-2
- test 1.18.2
- use new GTK bookmarks location if using GTK+-3
- with fix for global-menus

* Wed Apr 05 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.18.1-2
- test properly fit expanded panel to smaller screen size
- http://git.mate-desktop.org/mate-panel/commit/?h=1.18&id=471d39d
- test https://github.com/mate-desktop/mate-panel/commit/be71ad6
- test status-notifier: Do not hide passive items
- test http://git.mate-desktop.org/mate-panel/commit/?h=1.18&id=72dab7d
- test Run dialog: Fix wrong history order
- test http://git.mate-desktop.org/mate-panel/commit/?h=1.18&id=82ded61
- test https://github.com/mate-desktop/mate-panel/pull/561
- test https://github.com/mate-desktop/mate-panel/pull/564
- test Use new GTK bookmarks location if using GTK+-3
- test https://github.com/mate-desktop/mate-panel/pull/568

* Wed Apr 05 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.18.1-1
- test 1.18.1

* Tue Mar 14 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.18.0-3
- test https://github.com/mate-desktop/mate-panel/pull/540
- test https://github.com/mate-desktop/mate-panel/pull/533
- test https://github.com/mate-desktop/mate-panel/pull/543
- test https://github.com/mate-desktop/mate-panel/pull/546
- test https://github.com/mate-desktop/mate-panel/pull/541
- test https://github.com/mate-desktop/mate-panel/pull/542

* Tue Mar 14 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.18.0-2
- test https://github.com/mate-desktop/mate-panel/pull/540

* Tue Mar 14 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.18.0-1
- update to 1.18.0 release

* Thu Jan 19 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.2-1
- test to 1.17.2 release

* Thu Jan 19 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.1-1
- update to 1.17.1 release

* Sat Dec 03 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.0-1
- update to 1.17.0 release
- don't build with --with-in-process-applets=none

* Sat Sep 17 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.16.0-1
- test 1.16.0 release

* Thu Jun 09 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.15.1-2
- test GtkSeat fixes

* Thu Jun 09 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.15.1-1
- test 1.15.1 release
- test for f25, build with with-in-process-applets=none

* Thu Jun 09 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.15.0-3
- test mate-panel_0004-ditem-editor-port-to-GtkGrid.patch
- disable port to gweather, does not work
- test GtkAbout

* Thu Jun 09 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.15.0-2
- test https://github.com/mate-desktop/mate-panel/pull/449

* Thu Jun 09 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.15.0-1
- update to 1.15.0 release
- switch to gtk+3

* Wed Jun 08 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.14.1-11
- update to 1.14.1 release

* Sat May 21 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.14.0-12
- upstream fix for rhbz (#1238820) and (#1279101)

* Wed Apr 06 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.14.0-11
- update to 1.14.0 release

* Sun Mar 27 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.13.2-11
- update to 1.13.2 release

* Sun Feb 21 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.13.1-11
- update to 1.13.1 release

* Mon Jan 25 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.13.0-13
- test, GTkGrid port

* Mon Jan 25 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.13.0-12
- test css names

* Mon Jan 25 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.13.0-11
- update to 1.13.0 release

* Sat Jan 02 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.12.1-12
- add drawer fix
- fix rendering user background if not transparent
- add missing layout file for epel7

* Fri Dec 04 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> 1.12.1-11
- update to 1.12.1 release
- removed upstreamed patches

* Sat Nov 28 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.12.0-12
- fix crash if moving transparency slider too fast in preferences
- improvement for panel launchers

* Sat Oct 31 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.12.0-11
- update to 1.12.0 release

* Tue Oct 27 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.11.1-11
- update to 1.11.1 release
- remove upstreamed patches

* Fri Oct 09 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.11.0-12
- test, https://github.com/mate-desktop/mate-panel/pull/355
 
* Fri Oct 09 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.11.0-11
- update to 1.11.0 release

* Tue Oct 06 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.11.0-0.1.git20151006.4115bb9
- update to latest git from 2015-10-06
- remove upstreamed patch

* Sun Sep 06 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.2-10.6.git20150904.3c21f66
- test, theming patches

* Sun Sep 06 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.2-10.5.git20150904.3c21f66
- test, https://github.com/mate-desktop/mate-panel/pull/351

* Sun Sep 06 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.2-10.4.git20150904.3c21f66
- update to git snapshot from 2015-09-04
- drop upstreamed patches

* Thu Aug 06 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.2-10.3.git20150714.59c66fd
- update to git snapshot from 2015-07-14
- fix https://github.com/mate-desktop/mate-panel/issues/330
- fixes program list

* Thu Aug 06 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.1-12
- use http://git.mate-desktop.org/mate-panel/commit/?id=8c14769
- use http://git.mate-desktop.org/mate-panel/commit/?id=8b65935
- use http://git.mate-desktop.org/mate-panel/commit/?id=59c66fd
- fix https://github.com/mate-desktop/mate-panel/issues/330
- fixes program list

* Fri Jul 10 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.1-11
- update to 1.10.1 release
- remove upstreamed patches

* Fri Jul 03 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.0-16
- use old help from 1.8

* Mon Jun 29 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.0-15
- fix kill applet

* Sun Jun 28 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.0-14
- test, https://github.com/mate-desktop/mate-panel/pull/317

* Sun Jun 28 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.0-13
- add help from 1.8.x

* Fri May 22 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.0-12
- add upstream patch
- clean fedora panel layout
- remove unrecognized options --enable-network-manager
- remove libnm-gtk BR

* Tue May 05 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.0-11
- update to 1.10.0 release

* Thu Apr 09 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.91-11
- update to 1.9.91-1 release
- remove upstreamed patches

* Mon Mar 02 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.90-10
- update to 1.9.90 release

* Tue Jan 27 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.4-10
- bump version to more than ten

* Sun Nov 23 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.4-1
- test build 1.9.4 release

* Sun Nov 23 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.3-2
- test, try fix rhbz (#1023604)

* Sun Nov 23 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.3-1
- update to 1.9.3 release

* Tue Nov 11 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.2-1
- update to 1.9.2 release

* Sat Apr 12 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.1-1
- upate to 1.9.1 release

* Sat Apr 12 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.0-4
- use snapshot from 2014.06.29

* Sat Apr 12 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.0-3
- use snapshot from 2014.06.09
- remove patches from 1.9.0-3 test build

* Sat Apr 12 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.0-2
- use upstream 1.9.0 source

* Sat Apr 12 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.0-1
- test, mate-1.9 with GTK3

* Wed Mar 05 2014 Dan Mashal <dan.mashal@fedoraproject.org> - 1.8.0-1
- Update to 1.8.0

* Sat Feb 22 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.7.91-0.1.git20140222.838555a
- update to git snapshot from 2014.02.22
- use new panel layout file

* Tue Feb 18 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.7.90-1
- update to 1.7.90
- add --enable-gtk-doc configure flag
- move autoreconf to the right place

* Thu Feb 13 2014 Dan Mashal <dan.mashal@fedoraproject.org> - 1.7.2-2
- Add autoreconf -fi to work around rpath.

* Sun Feb 09 2014 Dan Mashal <dan.mashal@fedoraproject.org> - 1.7.2-1
- Update to 1.7.2

* Tue Jan 14 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.7.1-1
- update to 1.7.1 release
- use gtk-docs for release build
- remove obsolete BR --disable-scrollkeeper

* Sat Dec 21 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.7.1-0.2.git20131212.f4c7c8f
- make Maintainers life easier and use better git snapshot usage, Thanks to Björn Esser
- use requires caja-schemas
- use isa tag for -libs subpackage
- use modern 'make install' macro
- fix usage of %%{buildroot} or $RPM_BUILD_ROOT
- use better macro for SOURCE1
- move rpm scriptlets for -libs subpackage to the right place
- fix unused-direct-shlib-dependency rpmlint warning
- move %%{_libdir}/girepository-1.0/MatePanelApplet-4.0.typelib to -libs subpackage
- improve find language command for yelp-tools

* Thu Dec 12 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.7.1-0.1.gitbeb21bb
- update to latest git snapshot
- fix refer to cairo-gobject, noticed by M.Schwendt
- fix usage of wrong git snapshot tarball, 1.7.0 is released!
- no need of calling autotools when using autogen.sh

* Fri Dec 06 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.7.0-1.1.gitd2a24b9
- Update to 1.7.0
- Use latest upstream git as released version fails to build with gtk2 

* Thu Sep 12 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.1-4
- add runtime require mate-file-manager-schemas, fix rhbz (#1007219)

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Jul 19 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.1-2
- update panel-default-layout.dist for caja-1.6.2

* Thu Jul 18 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.1-1
- update to 1.6.1
- add upstream patch to fix partially
- https://github.com/mate-desktop/mate-panel/issues/111
- remove needless BR gsettings-desktop-schemas-devel

* Sat Jun 15 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.0-3
- remove gsettings convert file

* Fri May 31 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.0-2
- set default panel layout, add panel-default-layout.dist file
- add requires hicolor-icon-theme

* Wed Apr 03 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.6.0-1
- Update to latest 1.6.0 stable release.

* Wed Mar 27 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.5.6-2
- Remove ---with-in-process-applets configure flag as per upstream advice

* Tue Mar 26 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.5.6-1
- Update to latest upstream release

* Fri Feb 08 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.5.5-1
-Update to latest upstream release

* Sun Jan 20 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.5.4-1
- Update to latest upstream release
- Convert back to old BR style and sort BRs

* Fri Dec 21 2012 Nelson Marques <nmarques@fedoraproject.org> - 1.5.3-1
- Update to version 1.5.3
- Remove deprecated patches
- Improved readability without harming current style

* Tue Dec 18 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.5.2-5
- Fix crash on panel delete

* Tue Nov 27 2012 Rex Dieter <rdieter@fedoraproject.org> 1.5.2-4
- fix -libs subpkg, %%doc COPYING.LIB
- spec cleanup (whitespace mostly)
- fix icon scriptlet

* Mon Nov 26 2012 Dan Mashal <dan.mashal@fedoraproject.org> - 1.5.2-2
- Move libmate-panel-applet-4.so to separate libs package as mate-power-manager depends on it

* Thu Nov 22 2012 Dan Mashal <dan.mashal@fedoraproject.org> - 1.5.2-1
- Update to 1.5.2 release

* Mon Oct 29 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.5.1-1
- update to 1.5.1 release
- add schema scriptlets and remove mateconf scriptlets
- add requires gsettings-desktop-schemas
- add build requires gsettings-desktop-schemas-devel and dconf-devel
- move .gir file to devel package
- clean up spec file
- patch for new dconf api

* Mon Oct 22 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.4.0-12
- Remove un-needed %%check section

* Mon Oct 22 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.4.0-11
- add requires mate-session-manager
- change style for build requirements

* Wed Oct 10 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.4.0-10
- remove ugly hack
- set panel-default-setup.entries

* Sun Oct 07 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.4.0-9
- Change %%define to %%global
- Tidy up schema scriplets
- Tidy up %%build section

* Sun Oct 07 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.4.0-8
- Add ugly hack for panel-default-setup.entries

* Sat Oct 06 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.4.0-7
- Add enable-introspection and --with-x to configure flags
- Update desktop-file-install macro
- Update BR
- Turn desktop-file-validate back on
- Add fortune-mod to requires for fish to work properly.

* Wed Oct 03 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.4.0-6
- Add posttrans scriptlet to update icon cache and fix ordering of scriptlets
- Add comment about licensing

* Wed Oct 03 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.4.0-5
- Fix typo for netowrkmanager devel package on f18 

* Tue Oct 02 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.4.0-4
- Fix directory ownership, fix libexec configure flag
- Fix schema installation.. totally off

* Tue Oct 02 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.4.0-3
- Fix buildrequires for networkmanager rename in f18 as per juhp

* Wed Sep 26 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.4.0-2
- Fix mateconf scriptlets

* Sat Sep 01 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.4.0-1
-Initial build

